Atramhasis
==========

.. image:: https://img.shields.io/pypi/v/atramhasis.svg
        :target: https://pypi.python.org/pypi/atramhasis
.. image:: https://readthedocs.org/projects/atramhasis/badge/?version=latest
        :target: http://atramhasis.readthedocs.io/en/latest/?badge=latest
.. image:: https://travis-ci.org/OnroerendErfgoed/atramhasis.png?branch=master
        :target: https://travis-ci.org/OnroerendErfgoed/atramhasis?branch=master
.. image:: https://coveralls.io/repos/github/OnroerendErfgoed/atramhasis/badge.svg?branch=master
        :target: https://coveralls.io/github/OnroerendErfgoed/atramhasis?branch=master
.. image:: https://scrutinizer-ci.com/g/OnroerendErfgoed/atramhasis/badges/quality-score.png?b=master
        :target: https://scrutinizer-ci.com/g/OnroerendErfgoed/atramhasis/?branch=master

Atramhasis is an online SKOS editor. This webapplication enables
users to create SKOS vocabularies consisting of Concepts and Collections. It 
tries to stay close to the SKOS specification. This makes it suited for different
types of vocabularies such as simple pick lists, authority files, flat lists and
basic to relatively complex thesauri. Atramhasis is not suited for managing very
large or complex thesauri such as the `AAT <http://vocab.getty.edu>`_. 
